/* Cytec IF11 Test Program                     */

/* NOTES:                                     */
/* 1. Modify Include Paths for Your System    */
/* 2. Initialize address must match the       */
/*    hardware address set on the module      */

#include <utility.h>
#include <ansi_c.h>
#include <gpib.h>
#include <formatio.h>
#include "cy_if11.h"  /* Cytec IF-11 IEEE488 Matrix Control */

main()
{
	int err, mod, rly, instrID, status;
	int n, n_mtxs, n_mods, n_rlys;
	char s[128];

/* initialize IF11 */

	err = if11_init (7, 1, &instrID);
	if (err) {
		FmtOut("Error Initializing Cytec IF-11.\n");
		return;
	}
	Fmt(s,"z");
	err = if11_write(instrID, s);
	err = if11_read(instrID,127, s, &n);
	Delay(0.01);      
	n = Scan (s, "%d,%d,%d", &n_mtxs,&n_mods, &n_rlys);
	if (n!=3) {
		n_mtxs = 1; n_mods = 8; n_rlys = 8;
	}
	err = if11_operate(instrID, 'C', 0, 0, &status);
	if (err)
		FmtOut("Error Clearing System.\n");
	if (status != 0)
		FmtOut("Error Clearing, %d.\n", status);

/* Cycle through all Points */
	for (mod=0; mod<n_mods; mod++)
		for (rly=0; rly<n_rlys; rly++) {
			if11_operate(instrID, 'L', mod, rly, &status);
			if (status != 1)
				FmtOut("Error Latching %d, %d, %d.\n", mod, rly, status);
			if11_operate(instrID, 'U', mod, rly, &status);
			if (status != 0)
				FmtOut("Error UnLatching %d, %d, %d.\n", mod, rly, status);
		}
	if11_close(instrID);    /* release handle */
}

/* end: Test Program */
